@@ -116,6 +116,17 @@ function validateFormFieldString($fieldname, $fielddata, $newfieldvalue)
 		        $returnvalue = ($newfieldvalue !== false ? true : 'invalidip');
 		    }
 		}
+                elseif (isset($fielddata['string_type']) && $fielddata['string_type'] == 'validate_ip_incl_private') {
+                    // check for empty value (it might be allowed)
+                    if (trim($newfieldvalue) == '') {
+                        $newfieldvalue = '';
+                        $returnvalue = 'stringmustntbeempty';
+                    } else {
+                        $newfieldvalue = validate_ip2($newfieldvalue, true, 'invalidip', true, true, true);
+                        $returnvalue = ($newfieldvalue !== false ? true : 'invalidip');
+                    }
+                }
+
 		elseif (preg_match('/^[^\r\n\t\f\0]*$/D', $newfieldvalue)) {
 			$returnvalue = true;
 		}
