@@ -29,11 +29,11 @@ class pdns extends DnsBase
 		// connect to db
 		$this->_connectToPdnsDb();
 
-		// clean up
-		$this->_clearZoneTables();
-
 		$domains = $this->getDomainList();
 
+		// clean up
+		$this->_clearZoneTables($domains);
+
 		if (empty($domains)) {
 			$this->_logger->logAction(CRON_ACTION, LOG_INFO, 'No domains found for nameserver-config, skipping...');
 			return;
@@ -62,7 +62,7 @@ class pdns extends DnsBase
 		}
 
 		if ($domain['zonefile'] == '') {
-			// check for system-hostname
+		// check for system-hostname
 			$isFroxlorHostname = false;
 			if (isset($domain['froxlorhost']) && $domain['froxlorhost'] == 1) {
 				$isFroxlorHostname = true;
@@ -91,19 +91,30 @@ class pdns extends DnsBase
 			}
 		} else {
 			$this->_logger->logAction(CRON_ACTION, LOG_ERROR,
-				'Zonefiles are NOT supported when PowerDNS is selected as DNS daemon (triggered by: ' .
+				'Custom zonefiles are NOT supported when PowerDNS is selected as DNS daemon (triggered by: ' .
 				$domain['domain'] . ')');
-			$this->_bindconf_file .= $this->_generateDomainConfig($domain);
 		}
 	}
 
-	private function _clearZoneTables()
+	private function _clearZoneTables($domains = null)
 	{
 		$this->_logger->logAction(CRON_ACTION, LOG_INFO, 'Cleaning dns zone entries from database');
 
-		$this->pdns_db->query("TRUNCATE TABLE `records`");
-		$this->pdns_db->query("TRUNCATE TABLE `domains`");
-		$this->pdns_db->query("TRUNCATE TABLE `domainmetadata`");
+		$pdns_domains_stmt = $this->pdns_db->prepare("SELECT `id`, `name` FROM `domains` WHERE `name` = :domain");
+
+		$del_rec_stmt = $this->pdns_db->prepare("DELETE FROM `records` WHERE `domain_id` = :did");
+		$del_meta_stmt = $this->pdns_db->prepare("DELETE FROM `domainmetadata` WHERE `domain_id` = :did");
+		$del_dom_stmt = $this->pdns_db->prepare("DELETE FROM `domains` WHERE `id` = :did");
+
+		foreach ($domains as $domain)
+		{
+			$pdns_domains_stmt->execute(array('domain' => $domain['domain']));
+			$pdns_domain = $pdns_domains_stmt->fetch(\PDO::FETCH_ASSOC);
+
+			$del_rec_stmt->execute(array('did' => $pdns_domain['id']));
+			$del_meta_stmt->execute(array('did' => $pdns_domain['id']));
+			$del_dom_stmt->execute(array('did' => $pdns_domain['id']));
+		}
 	}
 
 	private function _insertZone($domainname, $serial = 0)
@@ -183,10 +194,8 @@ class pdns extends DnsBase
 			// AXFR server #100
 			if (count($this->_axfr) > 0) {
 				foreach ($this->_axfr as $axfrserver) {
-					if (validate_ip($axfrserver, true) !== false) {
-						$ins_data['value'] = $axfrserver;
-						$ins_stmt->execute($ins_data);
-					}
+					$ins_data['value'] = $axfrserver;
+					$ins_stmt->execute($ins_data);
 				}
 			}
 		}
